summaryrefslogtreecommitdiff
path: root/vendor/symfony/http-kernel/Exception/UnauthorizedHttpException.php
diff options
context:
space:
mode:
Diffstat (limited to 'vendor/symfony/http-kernel/Exception/UnauthorizedHttpException.php')
-rw-r--r--vendor/symfony/http-kernel/Exception/UnauthorizedHttpException.php4
1 files changed, 2 insertions, 2 deletions
diff --git a/vendor/symfony/http-kernel/Exception/UnauthorizedHttpException.php b/vendor/symfony/http-kernel/Exception/UnauthorizedHttpException.php
index bc42877fe8..7f7d0b4739 100644
--- a/vendor/symfony/http-kernel/Exception/UnauthorizedHttpException.php
+++ b/vendor/symfony/http-kernel/Exception/UnauthorizedHttpException.php
@@ -19,11 +19,11 @@ class UnauthorizedHttpException extends HttpException
/**
* @param string $challenge WWW-Authenticate challenge string
* @param string $message The internal exception message
* @param \Exception $previous The previous exception
* @param int $code The internal exception code
* @param array $headers
*/
- public function __construct(string $challenge, string $message = null, \Exception $previous = null, ?int $code = 0, array $headers = [])
+ public function __construct(string $challenge, string $message = null, \Throwable $previous = null, ?int $code = 0, array $headers = [])
{
$headers['WWW-Authenticate'] = $challenge;
@@ -19,11 +19,11 @@ class UnauthorizedHttpException extends HttpException
* @param string $challenge WWW-Authenticate challenge string
* @param string $message The internal exception message
- * @param \Exception $previous The previous exception
+ * @param \Throwable $previous The previous exception
* @param int $code The internal exception code
* @param array $headers